@@ -56,8 +56,8 @@ StylePlugin::~StylePlugin()
 
 QStringList StylePlugin::keys() const
 {
-    return QStringList() << QStringLiteral("Adwaita") << QStringLiteral("Adwaita-Dark")
-                         << QStringLiteral("Adwaita-HighContrast") << QStringLiteral("Adwaita-HighContrast-Dark");
+    return QStringList() << QStringLiteral("Adwaita") << QStringLiteral("Adwaita-Dark") << QStringLiteral("Adwaita-Light")
+                         << QStringLiteral("Adwaita-HighContrast") << QStringLiteral("Adwaita-HighContrastInverse");
 }
 
 } // namespace Adwaita
